package frc.robot.subsystems;

import com.revrobotics.CANSparkMax;
import com.revrobotics.CANSparkLowLevel.MotorType;

import edu.wpi.first.math.controller.PIDController;
import edu.wpi.first.wpilibj.Encoder;
import edu.wpi.first.wpilibj2.command.Command;
import edu.wpi.first.wpilibj2.command.SubsystemBase;
import frc.robot.constants.HoodConstants;

public class Hood extends SubsystemBase {
    private CANSparkMax motor1;

    private Encoder encoder;

    private PIDController pidController;

    public Hood() {
        motor1 = new CANSparkMax(HoodConstants.kMotor1ID, MotorType.kBrushless);

        encoder = new Encoder(HoodConstants.kEncoderA, HoodConstants.kEncoderB);

        pidController = new PIDController(
            HoodConstants.kHoodP, 
            HoodConstants.kHoodI, 
            HoodConstants.kHoodD
        );
    }

    public Command hoodUp() {
        return run(() -> {
            motor1.set(pidController.calculate(
                encoder.getDistance(), 
                HoodConstants.kHoodUpPosition));
        });
    }

    public Command hoodDown() {
        return run(() -> {
            motor1.set(pidController.calculate(
                encoder.getDistance(), 
                HoodConstants.kHoodDownPosition));
        });
    }

    public boolean atSetpoint() {
        return pidController.atSetpoint();
    }

    public double getEncoder() {
        return encoder.getDistance();
    }
}
