package frc.robot.subsystems;

import com.revrobotics.AbsoluteEncoder;
import com.revrobotics.CANSparkMax;
import com.revrobotics.CANSparkLowLevel.MotorType;

import edu.wpi.first.math.controller.PIDController;
import edu.wpi.first.wpilibj2.command.Command;
import edu.wpi.first.wpilibj2.command.SubsystemBase;
import frc.robot.constants.IntakePivotConstants;

public class IntakePivot extends SubsystemBase {
    private CANSparkMax motor1;

    private AbsoluteEncoder motor1Encoder;

    private PIDController pidController;

    public IntakePivot() {
        motor1 = new CANSparkMax(IntakePivotConstants.kMotor1ID, MotorType.kBrushless);

        motor1Encoder = motor1.getAbsoluteEncoder();

        pidController = new PIDController(
            IntakePivotConstants.kHoodP, 
            IntakePivotConstants.kHoodI, 
            IntakePivotConstants.kHoodD
        );
    }

    public Command intakeUp() {
        return run(() -> {
            motor1.set(pidController.calculate(
                motor1Encoder.getPosition(), 
                IntakePivotConstants.kIntakeUpPosition));
        });
    }

    public Command intakeDown() {
        return run(() -> {
            motor1.set(pidController.calculate(
                motor1Encoder.getPosition(), 
                IntakePivotConstants.kIntakeDownPosition));
        });
    }

    public boolean atSetpoint() {
        return pidController.atSetpoint();
    }
}
