package frc.robot.subsystems;

import java.util.function.DoubleSupplier;

import com.revrobotics.AbsoluteEncoder;
import com.revrobotics.CANSparkMax;
import com.revrobotics.CANSparkLowLevel.MotorType;

import edu.wpi.first.math.controller.BangBangController;
import edu.wpi.first.wpilibj2.command.Command;
import edu.wpi.first.wpilibj2.command.SubsystemBase;
import frc.robot.constants.ShooterConstants;

public class Shooter extends SubsystemBase {
    private CANSparkMax topRoller;
    private CANSparkMax bottomRoller;

    private AbsoluteEncoder topEncoder;

    private BangBangController bangBangController;

    public Shooter() {
        topRoller = new CANSparkMax(ShooterConstants.kTopRollerID, MotorType.kBrushless);
        bottomRoller = new CANSparkMax(ShooterConstants.kBottomRollerID, MotorType.kBrushless);
        
        bottomRoller.follow(topRoller);
        bottomRoller.setInverted(true);

        topEncoder = topRoller.getAbsoluteEncoder();

        bangBangController = new BangBangController(ShooterConstants.kBangBangTolerance);
    }

    public Command manualShooter(DoubleSupplier speed) {
        return run(() -> {
            topRoller.set(speed.getAsDouble());
        });
    }

    public Command setSpeedShooter(double speed) {
        return run(() -> {
            topRoller.set(
                bangBangController.calculate(
                    topEncoder.getVelocity(), 
                    speed
                )
            );
        });
    }

    public Command stopShooter() {
        return run(() -> {
            topRoller.set(0);
        });
    }

    public boolean atSetpoint() {
        return bangBangController.atSetpoint();
    }
}
